#!/usr/bin/env bash
#
# This scripts creates hql file which consists of CREATE DATABASE, CREATE TABLE, CREATE VIEW statements for all
# dbs, tables and views that are present in Hive meta-store. It also adds MSCK REPAIR TABLE for tables with
# partitions.
#

#
# Checks if table is partitioned
#
is_partitioned() {
  statement="$1"
  case $statement in
  *PARTITIONED*)
    return 0; # true
    ;;
  esac
  return 1; # false
}
#
# Main method
#
OUT=hive_tbl_dump.hql
rm -Rf "$OUT"
mapfile -t hive_dbs < <(hive -e "show databases;")
# processing Hive databases
for hive_db in "${hive_dbs[@]}"; do
  mapfile -t hive_tbls < <(hive -e "use $hive_db;show tables;")
  mapfile -t hive_vws < <(hive -e "use $hive_db;show views;")
  # remove views from table list
  for i in "${hive_vws[@]}"; do
     hive_tbls=(${hive_tbls[@]//*$i*})
  done
  {
    printf -- "--========================\n";
    printf "%s %s\n" "-- DATABASE" "$hive_db"
    printf -- "--========================\n";
    printf "CREATE DATABASE IF NOT EXISTS %s;\n" "$hive_db"
    printf "USE %s;\n" "$hive_db"
  }  >> "$OUT"
  # process Hive tables
  for hive_tbl in "${hive_tbls[@]}"; do
  create_tbl=$(hive -e "use $hive_db;show create table $hive_tbl;")
  {
    printf -- "--------------------------\n"
    printf "%s %s\n" "-- TABLE" "$hive_tbl"
    printf -- "--------------------------\n"
    printf "%s;\n" "$create_tbl"
  } >> "$OUT"
  # repair partitions
  if is_partitioned "$create_tbl"; then
  {
    printf -- "--------------------------\n"
    printf "%s %s\n" "-- REPAIRING PARTITIONS FOR TABLE" "$hive_tbl"
    printf -- "--------------------------\n"
    printf "MSCK REPAIR TABLE %s ADD PARTITIONS;\n" "$hive_tbl" >> "$OUT"
  } >> "$OUT"
  fi
  done
  # process Hive views
  for hive_vw in "${hive_vws[@]}"; do
  create_vw=$(hive -e "use $hive_db;show create table $hive_vw;")
  {
    printf -- "--------------------------\n"
    printf "%s %s\n" "-- VIEW" "$hive_vw"
    printf -- "--------------------------\n"
    printf "%s;\n" "$create_vw"
  } >> "$OUT"
  done
done
