package org.apache.hadoop.hive.conf;

import org.apache.commons.lang3.SystemUtils;
import org.apache.hadoop.hive.common.classification.InterfaceAudience.Private;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

@Private
public class MapRSecurityUtil {
  private static final Logger LOG = LoggerFactory.getLogger(MapRSecurityUtil.class.getName());
  private static final String MAPR_SEC_ENABLED = "mapr_sec_enabled";

    public static String findMapRHome() {
    String maprHome = System.getenv("MAPR_HOME");
    if (maprHome == null) {
      LOG.warn("Environment variable MAPR_HOME is null");
      maprHome = System.getProperty("mapr.home.dir");
      if (maprHome == null) {
        LOG.warn("System property mapr.home.dir is null");
        maprHome = SystemUtils.IS_OS_WINDOWS ? "C:/opt/mapr" : "/opt/mapr";
        LOG.warn("Setting MapR home as {} by default", maprHome);
      }
    }
    return maprHome;
  }

  public static boolean isClusterAdminProcess() {
    String currentUser = System.getProperty("user.name");
    String clusterAdmin = findAdminUser();
    if (currentUser != null && !currentUser.isEmpty() && clusterAdmin != null && !clusterAdmin.isEmpty()) {
      return currentUser.equals(clusterAdmin);
    }
    return false;
  }

  public static String findAdminUser() {
    String pathToDaemonConf = findMapRHome() + File.separator + "conf" + File.separator + "daemon.conf";
    try (InputStream is = new FileInputStream(pathToDaemonConf)) {
      Properties properties = new Properties();
      properties.load(is);
      return properties.getProperty("mapr.daemon.user");
    } catch (IOException e) {
      LOG.error(e.toString());
    }
    return "";
  }

  public static boolean isSecurityEnabled() {
    String mapRSecurityEnabled = System.getProperty(MAPR_SEC_ENABLED);
    if (!isSecurityFlagSet()) {
      return false;
    }
    return "true".equalsIgnoreCase(mapRSecurityEnabled.trim());
  }
  public static boolean isSecurityFlagSet() {
    String mapRSecurityEnabled = System.getProperty(MAPR_SEC_ENABLED);
    return mapRSecurityEnabled != null && !mapRSecurityEnabled.isEmpty();
  }
}
